# -*- coding: utf-8 -*-

# Copyright(C) 2012 Kevin Pouget
#
# This file is part of a woob module.
#
# This woob module is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This woob module is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this woob module. If not, see <http://www.gnu.org/licenses/>.

from .compat.woob_browser import AbstractBrowser, URL

from .linebourse_browser import LinebourseAPIBrowser
from .pages import JsFilePage, LoginPage, NewLoginPage, ConfigPage, IndexPage


__all__ = ['CaisseEpargneBrowser']


class CaisseEpargneBrowser(AbstractBrowser):
    PARENT = 'caissedepargne'
    PARENT_ATTR = 'package.browser.CaisseEpargne'

    BASEURL = 'https://www.credit-cooperatif.coop'
    CENET_URL = 'https://www.espaceclient.credit-cooperatif.coop'
    enseigne = 'ccoop'

    login = URL(
        r'https://www.credit-cooperatif.coop/authentification/manage\?step=identification&identifiant=(?P<login>.*)',
        r'https://.*/login.aspx',
        LoginPage
    )
    new_login = URL(r'https://www.credit-cooperatif.coop/se-connecter/sso', NewLoginPage)
    js_file = URL(r'https://www.credit-cooperatif.coop/se-connecter/main\..*.js$', JsFilePage)
    config_page = URL(
        r'https://www.credit-cooperatif.coop/ria/pas/configuration/config.json\?ts=(?P<timestamp>.*)',
        ConfigPage
    )

    # These are different than the URLs from Caisse d'Épargne, so we have to redeclare them
    # for them to be handled
    cons_details_form = URL(
        r'https://www.net.*.credit-cooperatif.coop/CreditConso/ReroutageSAV_PP.aspx',
        IndexPage
    )

    LINEBOURSE_BROWSER = LinebourseAPIBrowser

    def __init__(self, nuser, config, *args, **kwargs):
        kwargs['market_url'] = 'https://www.offrebourse.com'
        super(CaisseEpargneBrowser, self).__init__(nuser, config, *args, **kwargs)
